const { chromium } = require('playwright');

async function testEmailLogin() {
    console.log('Starting email login test...');
    let browser = null;
    
    try {
        console.log('Launching browser...');
        browser = await chromium.launch({
            headless: true,
            channel: 'chrome',
            args: ['--no-sandbox', '--disable-setuid-sandbox']
        });
        
        console.log('Browser launched successfully');
        
        const context = await browser.newContext();
        console.log('Browser context created');
        
        const page = await context.newPage();
        console.log('Page created');
        
        console.log('Navigating to lolipop login...');
        await page.goto('https://webmail.lolipop.jp/login');
        console.log('Navigation successful');
        
        // Fill login form
        console.log('Filling login form...');
        await page.fill('input[type="email"]', 'spdrakuten@spdsystem.com');
        await page.fill('input[type="password"]', 'YzFiMTJlYT2a4-4a');
        console.log('Form filled, clicking submit...');
        
        // Click login button
        await page.click('button[type="submit"]');
        
        // Wait for successful login
        console.log('Waiting for login to complete...');
        try {
            await page.waitForSelector('.css-1f8bwsm', { timeout: 10000 });
            console.log('Login successful!');
        } catch (error) {
            console.error('Login failed:', error);
            // Take screenshot of the failure
            await page.screenshot({ path: 'login-failed.png' });
            console.log('Screenshot saved as login-failed.png');
        }
        
    } catch (error) {
        console.error('Test failed:', error);
    } finally {
        if (browser) {
            console.log('Closing browser...');
            await browser.close();
            console.log('Browser closed');
        }
    }
}

testEmailLogin(); 