const { chromium } = require('playwright');

async function testBrowser() {
    console.log('Starting browser test...');
    let browser = null;
    
    try {
        console.log('Launching browser...');
        browser = await chromium.launch({
            headless: true,
            channel: 'chrome',
            args: ['--no-sandbox', '--disable-setuid-sandbox']
        });
        
        console.log('Browser launched successfully');
        
        const context = await browser.newContext();
        console.log('Browser context created');
        
        const page = await context.newPage();
        console.log('Page created');
        
        console.log('Navigating to google.com...');
        await page.goto('https://www.google.com');
        console.log('Navigation successful');
        
        const title = await page.title();
        console.log('Page title:', title);
        
        console.log('Test completed successfully');
    } catch (error) {
        console.error('Test failed:', error);
    } finally {
        if (browser) {
            console.log('Closing browser...');
            await browser.close();
            console.log('Browser closed');
        }
    }
}

testBrowser(); 